// Bristleback plugin - Copyright (c) 2010 bristleback.googlecode.com
// ---------------------------------------------------------------------------
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software Foundation; either version 3 of the License, or (at your
// option) any later version.
// This library is distributed in the hope that it will be useful,
// but without any warranty; without even the implied warranty of merchantability
// or fitness for a particular purpose.
// You should have received a copy of the GNU Lesser General Public License along
// with this program; if not, see <http://www.gnu.org/licenses/lgpl.html>.
// ---------------------------------------------------------------------------
package pl.bristleback.server.bristle.config;

import pl.bristleback.server.bristle.messages.MessageContainer;

/**
 * Classes implementing this interface are obligated to create message container,
 * which consists of message dispatcher and one or more message senders.
 * Any additional information or parameters required by implementation can be set in jwebsocket configuration file.
 * Implementations must be able to assign dispatcher to senders.
 * <p/>
 * Created on: 2010-09-25 10:22:51 <br/>
 *
 * @author Wojciech Niemiec
 */
public interface MessageContainerResolver {

  /**
   * Creates message container object containing message dispatcher and one or more message senders.
   * Any required parameters or setting must be specified by implementation and set in jwebsocket configuration file.
   *
   * @param configuration Bristleback plugin configuration.
   * @return message container.
   */
  MessageContainer createMessageContainer(BristleConfiguration configuration);

  /**
   * Assigns dispatcher to senders.
   *
   * @param messageContainer message container.
   */
  void assignDispatcherToSenders(MessageContainer messageContainer);
}
